Learn R Programming

lexiconPT (version 0.1.0)

sentiLex_lem_PT02: SentiLex-PT02

Description

A sentiment lexicon designed for the extraction of sentiment and opinion about human entities in Portuguese texts. Please see SILVA, CARVALHO, COSTA and SARMENTO (2010) for its complete reference and documentation.

Usage

sentiLex_lem_PT02

Arguments

Format

A data frame with 7014 rows and 5 variables:

term

character The word of term.

grammar_category

character. The grammar classification of the term.

polarity

double. Numeric classification of the polarity or sentiment.

polarity_target

character. Polarity target. It can be N0 (subject), N1 (complement) or N2 (no documentation was found for what it means).

polarity_classification

character. Was the polarity obtained manually (MAN) or automatically (JALC)?.